@@ -1,5 +1,9 @@
+use std::time::Duration;
+
 use mongodb::{options::ClientOptions, Client};
 
+use crate::Collection;
+
 pub struct Mungos {
     pub client: Client,
 }
